@@ -40,6 +40,9 @@ static char *api_extensions[] = {
 	"cgroup2",
 	"pidfd",
 	"seccomp_allow_deny_syntax",
+	"devpts_fd",
+	"seccomp_notify_fd_active",
+	"seccomp_proxy_send_notify_fd",
 };
 
 static size_t nr_api_extensions = sizeof(api_extensions) / sizeof(*api_extensions);
