@@ -382,8 +382,10 @@ ssize_t lxc_sendfile_nointr(int out_fd, int in_fd, off_t *offset, size_t count)
 	return ret;
 }
 
-int fd_to_fd(int from, int to)
+ssize_t __fd_to_fd(int from, int to)
 {
+	ssize_t total_bytes = 0;
+
 	for (;;) {
 		uint8_t buf[PATH_MAX];
 		uint8_t *p = buf;
@@ -397,6 +399,7 @@ int fd_to_fd(int from, int to)
 			break;
 
 		bytes_to_write = (size_t)bytes_read;
+		total_bytes += bytes_read;
 		do {
 			ssize_t bytes_written;
 
@@ -409,7 +412,7 @@ int fd_to_fd(int from, int to)
 		} while (bytes_to_write > 0);
 	}
 
-	return 0;
+	return total_bytes;
 }
 
 int fd_to_buf(int fd, char **buf, size_t *length)
@@ -550,3 +553,15 @@ int open_beneath(int dir_fd, const char *path, unsigned int flags)
 
 	return openat(dir_fd, path, O_NOFOLLOW | flags);
 }
+
+int fd_make_nonblocking(int fd)
+{
+	int flags;
+
+	flags = fcntl(fd, F_GETFL);
+	if (flags < 0)
+		return -1;
+
+	flags &= ~O_NONBLOCK;
+	return fcntl(fd, F_SETFL, flags);
+}
