@@ -1,25 +1,4 @@
-/*
- * lxc: linux Container library
- *
- * (C) Copyright IBM Corp. 2007, 2008
- *
- * Authors:
- * Daniel Lezcano <daniel.lezcano at free.fr>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
- */
+/* SPDX-License-Identifier: LGPL-2.1+ */
 
 #ifndef __LXC_LIST_H
 #define __LXC_LIST_H
@@ -79,19 +58,19 @@ static inline void lxc_list_add_elem(struct lxc_list *list, void *elem)
 }
 
 /* Retrieve first element of list. */
-static inline void *lxc_list_first_elem(struct lxc_list *list)
+static inline void *lxc_list_first_elem(const struct lxc_list *list)
 {
 	return list->next->elem;
 }
 
 /* Retrieve last element of list. */
-static inline void *lxc_list_last_elem(struct lxc_list *list)
+static inline void *lxc_list_last_elem(const struct lxc_list *list)
 {
 	return list->prev->elem;
 }
 
 /* Determine if list is empty. */
-static inline int lxc_list_empty(struct lxc_list *list)
+static inline int lxc_list_empty(const struct lxc_list *list)
 {
 	return list == list->next;
 }
