@@ -5,6 +5,8 @@
 
 #include <stdio.h>
 
+#include "compiler.h"
+
 struct rsync_data {
 	struct lxc_storage *orig;
 	struct lxc_storage *new;
@@ -16,9 +18,9 @@ struct rsync_data_char {
 };
 
 /* new helpers */
-extern int lxc_rsync_exec_wrapper(void *data);
-extern int lxc_storage_rsync_exec_wrapper(void *data);
-extern int lxc_rsync_exec(const char *src, const char *dest);
-extern int lxc_rsync(struct rsync_data *data);
+__hidden extern int lxc_rsync_exec_wrapper(void *data);
+__hidden extern int lxc_storage_rsync_exec_wrapper(void *data);
+__hidden extern int lxc_rsync_exec(const char *src, const char *dest);
+__hidden extern int lxc_rsync(struct rsync_data *data);
 
 #endif /* __LXC_RSYNC_H */
