@@ -862,21 +862,21 @@ int parse_byte_size_string(const char *s, int64_t *converted)
 	char suffix[3] = {0};
 
 	if (!s || !strcmp(s, ""))
-		return -EINVAL;
+		return ret_errno(EINVAL);
 
 	end = stpncpy(dup, s, sizeof(dup) - 1);
 	if (*end != '\0')
-		return -EINVAL;
+		return ret_errno(EINVAL);
 
 	if (isdigit(*(end - 1)))
 		suffix_len = 0;
 	else if (isalpha(*(end - 1)))
 		suffix_len = 1;
 	else
-		return -EINVAL;
+		return ret_errno(EINVAL);
 
 	if (suffix_len > 0 && (end - 2) == dup && !isdigit(*(end - 2)))
-		return -EINVAL;
+		return ret_errno(EINVAL);
 
 	if (suffix_len > 0 && isalpha(*(end - 2)))
 		suffix_len++;
@@ -889,8 +889,8 @@ int parse_byte_size_string(const char *s, int64_t *converted)
 	dup[lxc_char_right_gc(dup, strlen(dup))] = '\0';
 
 	ret = lxc_safe_long_long(dup, &conv);
-	if (ret < 0)
-		return -ret;
+	if (ret)
+		return ret;
 
 	if (suffix_len != 2) {
 		*converted = conv;
@@ -904,11 +904,11 @@ int parse_byte_size_string(const char *s, int64_t *converted)
 	else if (strcasecmp(suffix, "GB") == 0)
 		mltpl = 1024 * 1024 * 1024;
 	else
-		return -EINVAL;
+		return ret_errno(EINVAL);
 
 	overflow = conv * mltpl;
 	if (conv != 0 && (overflow / conv) != mltpl)
-		return -ERANGE;
+		return ret_errno(ERANGE);
 
 	*converted = overflow;
 	return 0;
